==> texworks_0.6.1.orig.tar.gz: texworks-release-0.6.1/modules/QtPDF/trans/QtPDF_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh">
<context>
    <name>QtPDF</name>
    <message>
        <source>[language name]</source>
        <translation type="unfinished">简体中文 (Simplified Chinese)</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation type="unfinished">&lt;a href=&quot;mailto:crickzhang1@gmail.com&quot;&gt;Yinhe Zhang&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentScene</name>
    <message>
        <source>rendering page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlock PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the password to unlock the PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The password you entered was incorrect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This document is locked. You need a password to open it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentView</name>
    <message>
        <source>Insufficient permission</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text extraction is not allowed for this document.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Goto page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Execute `%1`</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Table of Contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Processing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Producer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modification date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trapped:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished">字体</translation>
    </message>
    <message>
        <source>Type 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type 1 (multiple master)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TrueType</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>yes</source>
        <translation type="unfinished">是</translation>
    </message>
    <message>
        <source>no</source>
        <translation type="unfinished">否</translation>
    </message>
    <message>
        <source>[embedded]</source>
        <translation type="unfinished">[已嵌入]</translation>
    </message>
    <message>
        <source>[builtin]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">名称</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">类型</translation>
    </message>
    <message>
        <source>Subset</source>
        <translation type="unfinished">子集</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low resolution only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Denied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assembling only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accessibility support only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modifications:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extraction:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filling forms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents</source>
        <translation type="unfinished">目录</translation>
    </message>
</context>
</TS>

==> texworks_0.6.2.orig.tar.gz: texworks-release-0.6.2/modules/QtPDF/trans/QtPDF_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh">
<context>
    <name>QtPDF</name>
    <message>
        <source>[language name]</source>
        <translation>简体中文 (Simplified Chinese)</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>&lt;a href=&quot;mailto:crickzhang1@gmail.com&quot;&gt;Yinhe Zhang&lt;/a&gt; 和 &lt;a href=&quot;mailto:073plan@gmail.com&quot;&gt;Boyuan Yang&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentScene</name>
    <message>
        <source>rendering page</source>
        <translation>渲染页面</translation>
    </message>
    <message>
        <source>Unlock PDF</source>
        <translation>解锁 PDF</translation>
    </message>
    <message>
        <source>Please enter the password to unlock the PDF</source>
        <translation>请输入密码以解锁 PDF</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>密码不正确</translation>
    </message>
    <message>
        <source>The password you entered was incorrect.</source>
        <translation>您输入的密码不正确。</translation>
    </message>
    <message>
        <source>This document is locked. You need a password to open it.</source>
        <translation>这个文档已被锁定。您需要输入密码来打开文件。</translation>
    </message>
    <message>
        <source>Unlock</source>
        <translation>解锁</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentView</name>
    <message>
        <source>Insufficient permission</source>
        <translation>权限不足</translation>
    </message>
    <message>
        <source>Text extraction is not allowed for this document.</source>
        <translation>本文档不允许提取文字。</translation>
    </message>
    <message>
        <source>Goto page %1</source>
        <translation>前往 %1 页</translation>
    </message>
    <message>
        <source>Execute `%1`</source>
        <translation>运行 `%1`</translation>
    </message>
    <message>
        <source>Table of Contents</source>
        <translation>目录</translation>
    </message>
    <message>
        <source>Meta Data</source>
        <translation>元数据</translation>
    </message>
    <message>
        <source>Processing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其它</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>文档</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>标题：</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>作者：</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>主题：</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>关键字：</translation>
    </message>
    <message>
        <source>Creator:</source>
        <translation>创建者：</translation>
    </message>
    <message>
        <source>Producer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date:</source>
        <translation>创建日期：</translation>
    </message>
    <message>
        <source>Modification date:</source>
        <translation>修改日期：</translation>
    </message>
    <message>
        <source>Trapped:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>字体</translation>
    </message>
    <message>
        <source>Type 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type 1 (multiple master)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TrueType</source>
        <translation>TrueType</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <source>[embedded]</source>
        <translation>[已嵌入]</translation>
    </message>
    <message>
        <source>[builtin]</source>
        <translation>[内建]</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Subset</source>
        <translation>子集</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low resolution only</source>
        <translation>仅低分辨率</translation>
    </message>
    <message>
        <source>Denied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assembling only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accessibility support only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modifications:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extraction:</source>
        <translation>提取：</translation>
    </message>
    <message>
        <source>Annotation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filling forms:</source>
        <translation>填充表格：</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page</source>
        <translation>页面</translation>
    </message>
    <message>
        <source>Subject</source>
        <translation>主题</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>作者</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>目录</translation>
    </message>
</context>
</TS>
